==> 5.8.0.tar.gz: ciphey/translations/nl/CODE_OF_CONDUCT.md <==
# Gedragscode voor Bijdragersconvenant

## Onze belofte

In het belang van het bevorderen van een open en gastvrije omgeving, beloven wij als
bijdragers en onderhouders het deelnemen aan ons project en
onze gemeenschap een intimidatie-vrije ervaring voor iedereen, ongeacht leeftijd, 
lichaamsgrootte, handicap, etniciteit, geslachtskenmerken, genderidentiteit en expressie,
ervaringsniveau, opleiding, sociaaleconomische status, nationaliteit, uiterlijk, 
ras, religie of seksuele identiteit en geaardheid.

## Onze normen
Voorbeelden van gedrag dat bijdraagt aan het creëren van een positieve omgeving
omvatten:

* Gastvrije en inclusieve taal gebruiken
* Respectvol zijn voor verschillende standpunten en ervaringen
* Constructieve kritiek aanvaarden
* Focussen op wat het beste is voor de gemeenschap
* Empathie tonen naar andere leden van de gemeenschap

Voorbeelden van onaanvaardbaar gedrag van deelnemers omvatten:

* Het gebruik van geseksualiseerde taal of beelden en ongewenste seksuele aandacht
* Trollen, beledigende / denigrerende opmerkingen en persoonlijke of politieke aanvallen
* Intimidatie in het openbaar of privé 
* Het publiceren van privégegevens van anderen, zoals fysieke of elektronische adressen,
 zonder uitdrukkelijke toestemming
* Ander gedrag dat redelijkerwijs als ongepast zou kunnen worden beschouwd in een
  professionele setting

## Onze verantwoordelijkheden

Projectbeheerders zijn verantwoordelijk voor het verduidelijken van de normen van aanvaardbaar
gedrag en wordt verwacht dat ze passende en eerlijke corrigerende maatregelen nemen in
reactie op gevallen van onaanvaardbaar gedrag.

Projectbeheerders hebben het recht en de verantwoordelijkheid om opmerkingen, commits, 
code, wiki-bewerkingen, issues en andere contributies die niet in overeenstemming zijn 
met deze Gedragscode te verwijderen, bewerken of weigeren, of om tijdelijk of permanent
 de toegang te verbieden van elke bijdrager voor ander gedrag dat zij ongepast,
bedreigend, beledigend of schadelijk achten.

## Reikwijdte

Deze Gedragscode is zowel van toepassing binnen projectruimten als in openbare ruimten
wanneer een persoon het project of zijn gemeenschap vertegenwoordigt. Voorbeelden van
het vertegenwoordigen van een project of gemeenschap omvat het gebruik van een officiële project-e-mail
adres, posten via een officieel sociale media-account of optreden als een aangestelde
vertegenwoordiger bij een online of offline evenement. Wat onder de vertegenwoordiging 
van een project kan vallen kan verder gedefinieerd en verduidelijkt worden door projectbeheerders.

## Handhaving

Gevallen van grofheid, intimidatie of anderzijds onaanvaardbaar gedrag kan
gemeld worden door contact op te nemen met het projectteam op brandon_skerrit. Alle
klachten worden beoordeeld en onderzocht en resulteren in een reactie die 
noodzakelijk en passend  geacht worden onder de omstandigheden. Het projectteam is
verplicht tot geheimhouding met betrekking tot de melder van een incident.
Verdere details van het handhavingsbeleid kunnen afzonderlijk worden gepost.

Projectbeheerders die de Gedragscode niet in goed vertrouwen naleven of handhaven kunnen
tijdelijke of permanente gevolgen ondervinden, zoals bepaald door anderen
leden van de projectleiding.

## Attributie

Deze gedragscode is gebaseerd op de [Contributor Covenant][homepage], versie 1.4,
beschikbaar op https://www.contributor-covenant.org/version/1/4/code-of-conduct.html

[homepage]: https://www.contributor-covenant.org

Voor antwoorden op veelgestelde vragen over deze gedragscode, zie https://www.contributor-covenant.org/faq

==> 5.10.0.tar.gz: ciphey/translations/nl/CODE_OF_CONDUCT.md <==
# Gedragscode voor Bijdragersconvenant

## Onze belofte

In het belang van het bevorderen van een open en gastvrije omgeving, beloven wij als
bijdragers en onderhouders het deelnemen aan ons project en
onze gemeenschap een intimidatie-vrije ervaring voor iedereen, ongeacht leeftijd,
lichaamsgrootte, handicap, etniciteit, geslachtskenmerken, genderidentiteit en expressie,
ervaringsniveau, opleiding, sociaaleconomische status, nationaliteit, uiterlijk,
ras, religie of seksuele identiteit en geaardheid.

## Onze normen

Voorbeelden van gedrag dat bijdraagt aan het creëren van een positieve omgeving
omvatten:

- Gastvrije en inclusieve taal gebruiken
- Respectvol zijn voor verschillende standpunten en ervaringen
- Constructieve kritiek aanvaarden
- Focussen op wat het beste is voor de gemeenschap
- Empathie tonen naar andere leden van de gemeenschap

Voorbeelden van onaanvaardbaar gedrag van deelnemers omvatten:

- Het gebruik van geseksualiseerde taal of beelden en ongewenste seksuele aandacht
- Trollen, beledigende / denigrerende opmerkingen en persoonlijke of politieke aanvallen
- Intimidatie in het openbaar of privé
- Het publiceren van privégegevens van anderen, zoals fysieke of elektronische adressen,
  zonder uitdrukkelijke toestemming
- Ander gedrag dat redelijkerwijs als ongepast zou kunnen worden beschouwd in een
  professionele setting

## Onze verantwoordelijkheden

Projectbeheerders zijn verantwoordelijk voor het verduidelijken van de normen van aanvaardbaar
gedrag en wordt verwacht dat ze passende en eerlijke corrigerende maatregelen nemen in
reactie op gevallen van onaanvaardbaar gedrag.

Projectbeheerders hebben het recht en de verantwoordelijkheid om opmerkingen, commits,
code, wiki-bewerkingen, issues en andere contributies die niet in overeenstemming zijn
met deze Gedragscode te verwijderen, bewerken of weigeren, of om tijdelijk of permanent
de toegang te verbieden van elke bijdrager voor ander gedrag dat zij ongepast,
bedreigend, beledigend of schadelijk achten.

## Reikwijdte

Deze Gedragscode is zowel van toepassing binnen projectruimten als in openbare ruimten
wanneer een persoon het project of zijn gemeenschap vertegenwoordigt. Voorbeelden van
het vertegenwoordigen van een project of gemeenschap omvat het gebruik van een officiële project-e-mail
adres, posten via een officieel sociale media-account of optreden als een aangestelde
vertegenwoordiger bij een online of offline evenement. Wat onder de vertegenwoordiging
van een project kan vallen kan verder gedefinieerd en verduidelijkt worden door projectbeheerders.

## Handhaving

Gevallen van grofheid, intimidatie of anderzijds onaanvaardbaar gedrag kan
gemeld worden door contact op te nemen met het projectteam op brandon_skerrit. Alle
klachten worden beoordeeld en onderzocht en resulteren in een reactie die
noodzakelijk en passend geacht worden onder de omstandigheden. Het projectteam is
verplicht tot geheimhouding met betrekking tot de melder van een incident.
Verdere details van het handhavingsbeleid kunnen afzonderlijk worden gepost.

Projectbeheerders die de Gedragscode niet in goed vertrouwen naleven of handhaven kunnen
tijdelijke of permanente gevolgen ondervinden, zoals bepaald door anderen
leden van de projectleiding.

## Attributie

Deze gedragscode is gebaseerd op de [Contributor Covenant][homepage], versie 1.4,
beschikbaar op <https://www.contributor-covenant.org/version/1/4/code-of-conduct.html>

[homepage]: https://www.contributor-covenant.org

Voor antwoorden op veelgestelde vragen over deze gedragscode, zie <https://www.contributor-covenant.org/faq>
